@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2013                                                *
+ *  Copyright (c) 2001-2014                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -22,8 +22,8 @@ function action_confirmer_email_dist()
 
 	include_spip('inc/filtres');
 	if ($GLOBALS['visiteur_session']['id_auteur'] AND email_valide($arg)){
-		$editer_auteur = charger_fonction('editer_auteur','action');
-		auteurs_set($GLOBALS['visiteur_session']['id_auteur'],array('email'=>$arg));
+		include_spip('action/editer_auteur');
+		auteur_modifier($GLOBALS['visiteur_session']['id_auteur'],array('email'=>$arg));
 	}
 	// verifier avant de rediriger pour invalider le message de confirmation
 	// si ca n'a pas marche
