@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2012                                                *
+ *  Copyright (c) 2001-2014                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -20,7 +20,7 @@ function exec_rechercher_dist()
 {
 	$id = intval(_request('id'));
 	$exclus = intval(_request('exclus'));
-	$rac = htmlentities(_request('rac'));
+	$rac = spip_htmlentities(_request('rac'));
 	$type = _request('type');
 	$do  = _request('do');
 	if (preg_match('/^\w*$/', $do))
@@ -106,7 +106,7 @@ function proposer_item ($ids, $titles, $rac, $type, $do)
 
 	if (!$ids)
 		return "<br /><br /><div style='padding: 5px; color: red;'><b>"
-		.htmlentities($type)
+		.spip_htmlentities($type)
 		."</b> :  "._T('avis_aucun_resultat')."</div>";
 
 	$ret = '';
