@@ -3,34 +3,47 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2013                                                *
+ *  Copyright (c) 2001-2014                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
+/**
+ * Gestion des charsets et des conversions
+ *
+ * Ce fichier contient les fonctions relatives à la gestion de charsets,
+ * à la conversion de textes dans différents charsets et
+ * propose des fonctions émulant la librairie mb si elle est absente
+ * 
+ * @package SPIP\Texte\Charsets
+**/
 
-//
+// securité
 if (!defined('_ECRIRE_INC_VERSION')) return;
 
 
-/*
- * charsets supportes en natif : voir les tables dans ecrire/charsets/
- * les autres charsets sont supportes via mbstring()
- */
-
-// http://doc.spip.org/@load_charset
-function load_charset ($charset = 'AUTO', $langue_site = 'AUTO') {
+/**
+ * Charge en mémoire la liste des caractères d'un charset
+ *
+ * Charsets supportes en natif : voir les tables dans ecrire/charsets/
+ * Les autres charsets sont supportes via mbstring()
+ * 
+ * @param string $charset
+ *     Charset à charger
+ *     Par défaut (AUTO), utilise le charset du site
+ * @return string|bool
+ *     Nom du charset
+ *     false si le charset n'est pas décrit dans le répertoire charsets/
+**/
+function load_charset ($charset = 'AUTO') {
 	if ($charset == 'AUTO')
 		$charset = $GLOBALS['meta']['charset'];
 	$charset = trim(strtolower($charset));
 	if (isset($GLOBALS['CHARSET'][$charset]))
 		return $charset;
 
-	if ($langue_site == 'AUTO')
-		$langue_site = $GLOBALS['meta']['langue_site'];
-
 	if ($charset == 'utf-8') {
 		$GLOBALS['CHARSET'][$charset] = array();
 		return $charset;
@@ -51,10 +64,13 @@ function load_charset ($charset = 'AUTO', $langue_site = 'AUTO') {
 	}
 }
 
-//
-// Verifier qu'on peut utiliser mb_string
-//
-// http://doc.spip.org/@init_mb_string
+
+/**
+ * Verifier qu'on peut utiliser mb_string
+ *
+ * @return bool
+ *     true si toutes les fonctions mb nécessaires sont présentes
+**/
 function init_mb_string() {
 	static $mb;
 
@@ -79,8 +95,17 @@ function init_mb_string() {
 	return ($mb == 1);
 }
 
-// Detecter les versions buggees d'iconv
-// http://doc.spip.org/@test_iconv
+/**
+ * Test le fonctionnement correct d'iconv
+ *
+ * Celui-ci coupe sur certaines versions la chaine
+ * quand un caractère n'appartient pas au charset
+ *  
+ * @link http://php.net/manual/fr/function.iconv.php
+ * 
+ * @return bool
+ *     true si iconv fonctionne correctement
+**/
 function test_iconv() {
 	static $iconv_ok;
 
@@ -97,9 +122,15 @@ function test_iconv() {
 	return ($iconv_ok == 1);
 }
 
-// Test de fonctionnement du support UTF-8 dans PCRE
-// (contournement bug Debian Woody)
-// http://doc.spip.org/@test_pcre_unicode
+
+/**
+ * Test de fonctionnement du support UTF-8 dans PCRE
+ *
+ * Contournement bug Debian Woody
+ * 
+ * @return bool
+ *     true si PCRE supporte l'UTF-8 correctement
+**/
 function test_pcre_unicode() {
 	static $pcre_ok = 0;
 
@@ -111,8 +142,18 @@ function test_pcre_unicode() {
 	return $pcre_ok == 1;
 }
 
-// Plages alphanumeriques (incomplet...)
-// http://doc.spip.org/@pcre_lettres_unicode
+/**
+ * Renvoie une plage de caractères alphanumeriques unicodes (incomplet...)
+ *
+ * Retourne pour une expression rationnelle une plage
+ * de caractères alphanumériques à utiliser entre crochets [$plage]
+ *
+ * @internal
+ *    N'est pas utilisé
+ *    Servait à inc/ortho passé dans le grenier
+ * @return string
+ *    Plage de caractères
+**/
 function pcre_lettres_unicode() {
 	static $plage_unicode;
 
@@ -132,17 +173,40 @@ function pcre_lettres_unicode() {
 	return $plage_unicode;
 }
 
-// Plage ponctuation de 0x2000 a 0x206F
-// (i.e. de 226-128-128 a 226-129-176)
-// http://doc.spip.org/@plage_punct_unicode
+
+/**
+ * Renvoie une plage de caractères de ponctuation unicode de 0x2000 a 0x206F
+ *
+ * Retourne pour une expression rationnelle une plage
+ * de caractères de ponctuation à utiliser entre crochets [$plage]
+ * (i.e. de 226-128-128 a 226-129-176)
+ *
+ * @internal
+ *    N'est pas utilisé
+ *    Servait à inc/ortho passé dans le grenier
+ * @return string
+ *    Plage de caractères
+**/
 function plage_punct_unicode() {
 	return '\xE2(\x80[\x80-\xBF]|\x81[\x80-\xAF])';
 }
 
-// corriger caracteres non-conformes : 128-159
-// cf. charsets/iso-8859-1.php (qu'on recopie ici pour aller plus vite)
-// on peut passer un charset cible en parametre pour accelerer le passage iso-8859-1 -> autre charset
-// http://doc.spip.org/@corriger_caracteres_windows
+/**
+ * Corriger des caractères non-conformes : 128-159
+ *
+ * Cf. charsets/iso-8859-1.php (qu'on recopie ici pour aller plus vite)
+ * On peut passer un charset cible en parametre pour accelerer le passage iso-8859-1 -> autre charset
+ * 
+ * @param string $texte
+ *     Le texte à corriger
+ * @param string $charset
+ *     Charset d'origine du texte
+ *     Par défaut (AUTO) utilise le charset du site
+ * @param string $charset_cible
+ *     Charset de destination (unicode par défaut)
+ * @return string
+ *     Texte corrigé
+**/
 function corriger_caracteres_windows($texte, $charset='AUTO', $charset_cible='unicode') {
 	static $trans;
 	
@@ -153,7 +217,8 @@ function corriger_caracteres_windows($texte, $charset='AUTO', $charset_cible='un
 	if ($charset=='AUTO') $charset = $GLOBALS['meta']['charset'];
 	if ($charset == 'utf-8') {
 		$p = chr(194);
-		if (strpos($texte,$p)===false) return $texte;
+		if (strpos($texte,$p)==false)
+			return $texte;
 	} else if ($charset == 'iso-8859-1') {
 		$p = '';
 	} else
@@ -205,11 +270,19 @@ function corriger_caracteres_windows($texte, $charset='AUTO', $charset_cible='un
 }
 
 
-//
-// Transformer les &eacute; en &#123;
-// $secure = true pour *ne pas convertir* les caracteres malins &lt; &amp; etc.
-//
-// http://doc.spip.org/@html2unicode
+
+/**
+ * Transforme les entités HTML en unicode
+ * 
+ * Transforme les &eacute; en &#123;
+ *
+ * @param string $texte
+ *     Texte à convertir
+ * @param bool $secure
+ *     true pour *ne pas convertir* les caracteres malins &lt; &amp; etc.
+ * @return string
+ *     Texte converti
+**/
 function html2unicode($texte, $secure=false) {
 	if (strpos($texte,'&') === false) return $texte;
 	static $trans = array();
@@ -229,10 +302,17 @@ function html2unicode($texte, $secure=false) {
 		);
 }
 
-//
-// Transformer les &eacute; en &#123;
-//
-// http://doc.spip.org/@mathml2unicode
+
+/**
+ * Transforme les entités mathématiques (MathML) en unicode
+ *
+ * Transforme &angle; en &#x2220; ainsi que toutes autres entités mathématiques
+ *
+ * @param string $texte
+ *     Texte à convertir
+ * @return string
+ *     Texte converti
+**/
 function mathml2unicode($texte) {
 	static $trans;
 	if (!$trans) {
@@ -247,12 +327,23 @@ function mathml2unicode($texte) {
 }
 
 
-//
-// Transforme une chaine en entites unicode &#129;
-//
-// Note: l'argument $forcer est obsolete : il visait a ne pas
-// convertir les accents iso-8859-1
-// http://doc.spip.org/@charset2unicode
+/**
+ * Transforme une chaine en entites unicode &#129;
+ *
+ * Utilise la librairie mb si elle est présente.
+ * 
+ * @internal
+ *     Note: l'argument $forcer est obsolete : il visait a ne pas
+ *     convertir les accents iso-8859-1
+ * 
+ * @param string $texte
+ *     Texte à convertir
+ * @param string $charset
+ *     Charset actuel du texte
+ *     Par défaut (AUTO), le charset est celui du site.
+ * @return string
+ *     Texte converti en unicode
+**/
 function charset2unicode($texte, $charset='AUTO' /* $forcer: obsolete*/) {
 	static $trans;
 
@@ -308,11 +399,21 @@ function charset2unicode($texte, $charset='AUTO' /* $forcer: obsolete*/) {
 	}
 }
 
-//
-// Transforme les entites unicode &#129; dans le charset specifie
-// Attention on ne transforme pas les entites < &#128; car si elles
-// ont ete encodees ainsi c'est a dessein
-// http://doc.spip.org/@unicode2charset
+
+/**
+ * Transforme les entites unicode &#129; dans le charset specifie
+ *
+ * Attention on ne transforme pas les entites < &#128; car si elles
+ * ont ete encodees ainsi c'est a dessein
+ * 
+ * @param string $texte
+ *     Texte unicode à transformer
+ * @param string $charset
+ *     Charset à appliquer au texte
+ *     Par défaut (AUTO), le charset sera celui du site.
+ * @return string
+ *     Texte transformé dans le charset souhaité
+**/
 function unicode2charset($texte, $charset='AUTO') {
 	static $CHARSET_REVERSE;
 	static $trans = array();
@@ -354,21 +455,59 @@ function unicode2charset($texte, $charset='AUTO') {
 }
 
 
-// Importer un texte depuis un charset externe vers le charset du site
-// (les caracteres non resolus sont transformes en &#123;)
-// http://doc.spip.org/@importer_charset
+/**
+ * Importer un texte depuis un charset externe vers le charset du site
+ *
+ * Les caracteres non resolus sont transformes en &#123;
+ * 
+ * @param string $texte
+ *     Texte unicode à importer
+ * @param string $charset
+ *     Charset d'origine du texte
+ *     Par défaut (AUTO), le charset d'origine est celui du site.
+ * @return string
+ *     Texte transformé dans le charset site
+**/
 function importer_charset($texte, $charset = 'AUTO') {
+	static $trans = array();
 	// on traite le cas le plus frequent iso-8859-1 vers utf directement pour aller plus vite !
-	if (($charset == 'iso-8859-1') && ($GLOBALS['meta']['charset']=='utf-8') && function_exists('utf8_encode')){
-		$texte = corriger_caracteres_windows($texte, 'iso-8859-1','unicode');
-		$texte = utf8_encode($texte);
+	if (($charset == 'iso-8859-1') && ($GLOBALS['meta']['charset']=='utf-8')){
+		$texte = corriger_caracteres_windows($texte, 'iso-8859-1',$GLOBALS['meta']['charset']);
+		if (init_mb_string()) {
+			if ($order = mb_detect_order() # mb_string connait-il $charset?
+			AND mb_detect_order($charset)) {
+				$s = mb_convert_encoding($texte, 'utf-8', $charset);
+			}
+			mb_detect_order($order); # remettre comme precedemment
+			return $s;
+		}
+		// Sinon, peut-etre connaissons-nous ce charset ?
+		if (!isset($trans[$charset])) {
+			global $CHARSET;
+			if ($cset = load_charset($charset)
+			AND is_array($CHARSET[$cset]))
+				foreach ($CHARSET[$cset] as $key => $val) {
+					$trans[$charset][chr($key)] = unicode2charset('&#'.$val.';');
+			}
+		}
+		if (count($trans[$charset]))
+			return str_replace(array_keys($trans[$charset]),array_values($trans[$charset]),$texte);
 		return $texte;
 	}
 	return unicode2charset(charset2unicode($texte, $charset));
 }
 
-// UTF-8
-// http://doc.spip.org/@utf_8_to_unicode
+
+/**
+ * Transforme un texte UTF-8 en unicode 
+ *
+ * Utilise la librairie mb si présente
+ * 
+ * @param string $source
+ *    Texte UTF-8 à transformer
+ * @return string
+ *    Texte transformé en unicode
+**/
 function utf_8_to_unicode($source) {
 
 	// mb_string : methode rapide
@@ -456,11 +595,20 @@ function utf_8_to_unicode($source) {
 	return $encodedString;
 }
 
-// UTF-32 ne sert plus que si on passe par iconv, c'est-a-dire quand
-// mb_string est absente ou ne connait pas notre charset
-// mais on l'optimise quand meme par mb_string
-// => tout ca sera osolete quand on sera surs d'avoir mb_string
-// http://doc.spip.org/@utf_32_to_unicode
+/**
+ * Transforme un texte UTF-32 en unicode 
+ *
+ * UTF-32 ne sert plus que si on passe par iconv, c'est-a-dire quand
+ * mb_string est absente ou ne connait pas notre charset.
+ *
+ * Mais on l'optimise quand meme par mb_string
+ * => tout ca sera osolete quand on sera surs d'avoir mb_string
+ * 
+ * @param string $source
+ *    Texte UTF-8 à transformer
+ * @return string
+ *    Texte transformé en unicode
+**/
 function utf_32_to_unicode($source) {
 
 	// mb_string : methode rapide
@@ -487,8 +635,18 @@ function utf_32_to_unicode($source) {
 
 }
 
-// Ce bloc provient de php.net, auteur Ronen
-// http://doc.spip.org/@caractere_utf_8
+
+/**
+ * Transforme un numéro unicode en caractère utf-8
+ * 
+ * Ce bloc provient de php.net
+ * @author Ronen
+ * 
+ * @param int $num
+ *    Numéro de l'entité unicode
+ * @return char
+ *    Caractère utf8 si trouvé, '' sinon
+**/
 function caractere_utf_8($num) {
 	if($num<128)
 		return chr($num);
@@ -501,7 +659,14 @@ function caractere_utf_8($num) {
 	return '';
 }
 
-// http://doc.spip.org/@unicode_to_utf_8
+/**
+ * Convertit un texte unicode en utf-8
+ * 
+ * @param string $texte
+ *     Texte à convertir
+ * @return string
+ *     Texte converti
+**/
 function unicode_to_utf_8($texte) {
 
 	// 1. Entites &#128; et suivantes
@@ -526,8 +691,14 @@ function unicode_to_utf_8($texte) {
 
 }
 
-// convertit les &#264; en \u0108
-// http://doc.spip.org/@unicode_to_javascript
+/**
+ * Convertit les unicode &#264; en javascript \u0108
+ * 
+ * @param string $texte
+ *     Texte à convertir
+ * @return string
+ *     Texte converti
+**/
 function unicode_to_javascript($texte) {
 	$vu = array();
 	while (preg_match(',&#0*([0-9]+);,S', $texte, $regs) AND !isset($vu[$regs[1]])) {
@@ -539,15 +710,28 @@ function unicode_to_javascript($texte) {
 	return $texte;
 }
 
-// convertit les %uxxxx (envoyes par javascript)
-// http://doc.spip.org/@javascript_to_unicode
+/**
+ * Convertit les %uxxxx (envoyés par javascript) en &#yyy unicode
+ * 
+ * @param string $texte
+ *     Texte à convertir
+ * @return string
+ *     Texte converti
+**/
 function javascript_to_unicode ($texte) {
 	while (preg_match(",%u([0-9A-F][0-9A-F][0-9A-F][0-9A-F]),", $texte, $regs))
 		$texte = str_replace($regs[0],"&#".hexdec($regs[1]).";", $texte);
 	return $texte;
 }
-// convertit les %E9 (envoyes par le browser) en chaine du charset du site (binaire)
-// http://doc.spip.org/@javascript_to_binary
+
+/**
+ * Convertit les %E9 (envoyés par le browser) en chaîne du charset du site (binaire)
+ * 
+ * @param string $texte
+ *     Texte à convertir
+ * @return string
+ *     Texte converti
+**/
 function javascript_to_binary ($texte) {
 	while (preg_match(",%([0-9A-F][0-9A-F]),", $texte, $regs))
 		$texte = str_replace($regs[0],chr(hexdec($regs[1])), $texte);
@@ -611,16 +795,31 @@ function translitteration_chiffree($car) {
 }
 
 
-// Reconnaitre le BOM utf-8 (0xEFBBBF)
-// http://doc.spip.org/@bom_utf8
+/**
+ * Reconnaitre le BOM utf-8 (0xEFBBBF)
+ *
+ * @param string $texte
+ *    Texte dont on vérifie la présence du BOM
+ * @return bool
+ *    true s'il a un BOM
+**/
 function bom_utf8($texte) {
 	return (substr($texte, 0,3) == chr(0xEF).chr(0xBB).chr(0xBF));
 }
-// Verifie qu'un document est en utf-8 valide
-// http://us2.php.net/manual/fr/function.mb-detect-encoding.php#50087
-// http://w3.org/International/questions/qa-forms-utf-8.html
-// note: preg_replace permet de contourner un "stack overflow" sur PCRE
-// http://doc.spip.org/@is_utf8
+
+/**
+ * Vérifie qu'une chaîne est en utf-8 valide
+ * 
+ * Note: preg_replace permet de contourner un "stack overflow" sur PCRE
+ * 
+ * @link http://us2.php.net/manual/fr/function.mb-detect-encoding.php#50087
+ * @link http://w3.org/International/questions/qa-forms-utf-8.html
+ * 
+ * @param string $string
+ *     Texte dont on vérifie qu'il est de l'utf-8
+ * @return bool
+ *     true si c'est le cas
+**/
 function is_utf8($string) {
 	return !strlen(
 	preg_replace(
@@ -635,7 +834,15 @@ function is_utf8($string) {
 	. ',sS',
 	'', $string));
 }
-// http://doc.spip.org/@is_ascii
+
+/**
+ * Vérifie qu'une chaîne est en ascii valide
+ * 
+ * @param string $string
+ *     Texte dont on vérifie qu'il est de l'ascii
+ * @return bool
+ *     true si c'est le cas
+**/
 function is_ascii($string) {
 	return !strlen(
 	preg_replace(
@@ -697,7 +904,21 @@ function transcoder_page($texte, $headers='') {
 //
 // Gerer les outils mb_string
 //
-// http://doc.spip.org/@spip_substr
+
+/**
+ * Coupe un texte selon substr()
+ *
+ * Coupe une chaîne en utilisant les outils mb* lorsque le site est en utf8
+ *
+ * @link http://fr.php.net/manual/fr/function.mb-substr.php
+ * @link http://www.php.net/manual/fr/function.substr.php
+ * 
+ * @param string $c         Le texte
+ * @param int $start        Début
+ * @param null|int $length  Longueur ou fin
+ * @return string
+ *     Le texte coupé
+**/
 function spip_substr($c, $start=0, $length = NULL) {
 	// Si ce n'est pas utf-8, utiliser substr
 	if ($GLOBALS['meta']['charset'] != 'utf-8') {
@@ -719,8 +940,21 @@ function spip_substr($c, $start=0, $length = NULL) {
 	return spip_substr_manuelle($c, $start, $length);
 }
 
-// version manuelle de substr utf8, pour php vieux et/ou mal installe
-// http://doc.spip.org/@spip_substr_manuelle
+
+/**
+ * Coupe un texte comme mb_substr()
+ *
+ * Version manuelle de substr utf8, pour php vieux et/ou mal installe
+ *
+ * @link http://fr.php.net/manual/fr/function.mb-substr.php
+ * @used-by spip_substr()
+ * 
+ * @param string $c         Le texte
+ * @param int $start        Début
+ * @param null|int $length  Longueur ou fin
+ * @return string
+ *     Le texte coupé
+**/
 function spip_substr_manuelle($c, $start, $length = NULL) {
 
 	// Cas pathologique
@@ -751,8 +985,42 @@ function spip_substr_manuelle($c, $start, $length = NULL) {
 	return spip_substr_manuelle($c, 0, spip_strlen($c)+$length);
 }
 
-// http://doc.spip.org/@spip_strlen
+/**
+ * Rend majuscule le premier caractère d'une chaîne utf-8
+ * 
+ * Version utf-8 d'ucfirst
+ * 
+ * @param string $c
+ *     La chaîne à transformer
+ * @return string
+ *     La chaîne avec une majuscule sur le premier mot 
+ */
+function spip_ucfirst($c){
+	// Si ce n'est pas utf-8, utiliser ucfirst 
+	if ($GLOBALS['meta']['charset'] != 'utf-8')
+		return ucfirst($c);
+	// Si on n'a pas mb_* on utilise ucfirst
+	if (!init_mb_string())
+		return ucfirst($c);
+	
+	$lettre1 = mb_strtoupper(spip_substr($c,0,1));
+	return $lettre1.spip_substr($c,1);
+}
+
+/**
+ * Retourne la longueur d'une chaîne utf-8
+ * 
+ * Version utf-8 de strlen
+ * 
+ * @param string $c
+ *     La chaîne à compter
+ * @return int
+ *     Longueur de la chaîne
+ */
 function spip_strlen($c) {
+	// On transforme les sauts de ligne pour ne pas compter deux caractères
+	$c = str_replace("\r\n", "\n", $c);
+	
 	// Si ce n'est pas utf-8, utiliser strlen
 	if ($GLOBALS['meta']['charset'] != 'utf-8')
 		return strlen($c);
