@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2013                                                *
+ *  Copyright (c) 2001-2014                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -14,19 +14,20 @@
 // (cette distinction est obsolete a present, on la garde provisoirement
 // par souci de compatiilite).
 
-if (isset($GLOBALS['_INC_PUBLIC'])) {
+if (isset($GLOBALS['_INC_PUBLIC']) AND $GLOBALS['_INC_PUBLIC']) {
 
 	echo recuperer_fond($fond, $contexte_inclus, array(), _request('connect'));
 
 } else {
 
-	$GLOBALS['_INC_PUBLIC'] = 0;
+	$GLOBALS['_INC_PUBLIC'] = 1;
+	define('_PIPELINE_SUFFIX',  test_espace_prive()?'_prive':'');
 
 	// Faut-il initialiser SPIP ? (oui dans le cas general)
 	if (!defined('_DIR_RESTREINT_ABS'))
 		if (defined('_DIR_RESTREINT')
-		AND @file_exists( _ROOT_RESTREINT . 'inc_version.php')) {
-			include_once  _ROOT_RESTREINT . 'inc_version.php';
+		AND @file_exists(_ROOT_RESTREINT . 'inc_version.php')) {
+			include_once _ROOT_RESTREINT . 'inc_version.php';
 		}
 		else
 			die('inc_version absent ?');
@@ -58,17 +59,8 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 			unset($_GET['action']);
 	# sinon, fond par defaut
 	} else {
-		// traiter le cas pathologique d'un upload de document ayant echoue
-		// car trop gros
-		if (empty($_GET) AND empty($_POST) AND empty($_FILES)
-		AND isset($_SERVER["CONTENT_LENGTH"])
-		AND strstr($_SERVER["CONTENT_TYPE"], "multipart/form-data;")) {
-			include_spip('inc/getdocument');
-			erreur_upload_trop_gros();
-		}
-
 		// sinon fond par defaut (cf. assembler.php)
-		$fond = '';
+		$fond = pipeline('detecter_fond_par_defaut','');
 	}
 
 	$tableau_des_temps = array();
@@ -77,7 +69,9 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 	if ($fond == 'login')
 		$forcer_lang = true;
 
-	if (isset($forcer_lang) AND $forcer_lang AND ($forcer_lang!=='non') AND !_request('action')) {
+	if (isset($forcer_lang) AND $forcer_lang AND ($forcer_lang!=='non')
+		AND !_request('action')
+		AND $_SERVER['REQUEST_METHOD'] != 'POST') {
 		include_spip('inc/lang');
 		verifier_lang_url();
 	}
@@ -96,16 +90,13 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 			traiter_appels_inclusions_ajax()
 		 OR
 			// cas des formulaires charger/verifier/traiter
-			traiter_formulaires_dynamiques())
+			traiter_formulaires_dynamiques()){
+			// lancer les taches sur affichage final, comme le cron
+			// mais sans rien afficher
+			$GLOBALS['html'] = false; // ne rien afficher
+			pipeline('affichage_final'._PIPELINE_SUFFIX, '');
 			exit; // le hit est fini !
-	}
-
-	// si signature de petition, l'enregistrer avant d'afficher la page
-	// afin que celle-ci contienne la signature
-
-	if (isset($_GET['var_confirm'])) {
-		$reponse_confirmation = charger_fonction('reponse_confirmation','formulaires/signature');
-		$reponse_confirmation($_GET['var_confirm']);
+		}
 	}
 
 	// Il y a du texte a produire, charger le metteur en page
@@ -117,87 +108,50 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 		http_status($page['status']);
 	}
 
-	// Tester si on est admin et il y a des choses supplementaires a dire
-	// type tableau pour y mettre des choses au besoin.
-	$debug = ((_request('var_mode') == 'debug') OR $tableau_des_temps) ? array(1) : array();
-
-	// Mettre le Content-Type Html si manquant 
-	// Idem si debug, avec retrait du Content-Diposition pour voir le voir
-
-	if ($debug OR !isset($page['entetes']['Content-Type'])) {
+	// Content-Type ?
+	if (!isset($page['entetes']['Content-Type'])) {
 		$page['entetes']['Content-Type'] = 
 			"text/html; charset=" . $GLOBALS['meta']['charset'];
-		if ($debug) unset($page['entetes']['Content-Disposition']);
 		$html = true;
 	} else {
 		$html = preg_match(',^\s*text/html,',$page['entetes']['Content-Type']);
 	}
 
-	$affiche_boutons_admin = ($debug OR ($html AND isset($_COOKIE['spip_admin']) AND !$flag_preserver));
+	// Tester si on est admin et il y a des choses supplementaires a dire
+	// type tableau pour y mettre des choses au besoin.
+	$debug = ((_request('var_mode') == 'debug') OR $tableau_des_temps) ? array(1) : array();
+
+	$affiche_boutons_admin = ($html AND (
+		(isset($_COOKIE['spip_admin']) AND (!isset($flag_preserver) OR !$flag_preserver))
+		OR $debug
+		OR (defined('_VAR_PREVIEW') AND _VAR_PREVIEW)
+	));
 
 	if ($affiche_boutons_admin)
 		include_spip('balise/formulaire_admin');
 
 
- 	// decompte des visites, on peut forcer a oui ou non avec le header X-Spip-Visites
- 	// par defaut on ne compte que les pages en html (ce qui exclue les js,css et flux rss)
- 	$spip_compter_visites = $html?'oui':'non';
- 	if (isset($page['entetes']['X-Spip-Visites'])){
-		$spip_compter_visites = in_array($page['entetes']['X-Spip-Visites'],array('oui','non'))?$page['entetes']['X-Spip-Visites']:$spip_compter_visites;
-		unset($page['entetes']['X-Spip-Visites']);
- 	}
-
 	// Execution de la page calculee
 
 	// traitements sur les entetes avant envoi
 	// peut servir pour le plugin de stats
-	$page['entetes'] = pipeline('affichage_entetes_final', $page['entetes']);
+	$page['entetes'] = pipeline('affichage_entetes_final'._PIPELINE_SUFFIX, $page['entetes']);
 
-	if ($page['process_ins'] != 'html') {
-	// Cas d'une page contenant du PHP :
-	// Attention cette partie eval() doit imperativement
-	// etre declenchee dans l'espace des globales (donc pas
-	// dans une fonction).
-	// inclure_balise_dynamique nous enverra peut-etre
-	// quelques en-tetes de plus (voire qq envoyes directement)
 
-		// restaurer l'etat des notes
-		if (isset($page['notes']) AND $page['notes']){
-			$notes = charger_fonction("notes","inc");
-			$notes($page['notes'],'restaurer_etat');
-		}
-		ob_start(); 
-		xml_hack($page, true);
-		$page['process_ins'] = eval('?' . '>' . $page['texte']);
-		$page['texte'] = ob_get_contents(); 
-		xml_hack($page);
-		ob_end_clean();
-	}
-
-	if ($var_preview
-	AND $var_preview = charger_fonction('previsualisation', 'public', true)) {
-		$page = $var_preview($page);
-		// Cette variable a ete calculee trop tot
-		// on laisse son calcul ci-dessus pour compatibilite
-		// bien que l'enlever a l'air sans incidence
-		$html = preg_match(',^\s*text/html,',$page['entetes']['Content-Type']);
-	}
+	// eval $page et affecte $res
+	include _ROOT_RESTREINT."public/evaluer_page.php";
 	envoyer_entetes($page['entetes']);
-
-	// en cas d'erreur lors du eval,
-	// la memoriser dans le tableau des erreurs
-	if ($page['process_ins'] === false) {
-			$msg = array('zbug_erreur_execution_page');
-			erreur_squelette($msg);
+	if ($res === false) {
+		$msg = array('zbug_erreur_execution_page');
+		erreur_squelette($msg);
 	}
-	//
-	// Post-traitements
-	//
-	page_base_href($page['texte']);
 
+	//
+	// Envoyer le resultat apres post-traitements
+	//
 	// (c'est ici qu'on fait var_recherche, validation, boutons d'admin,
 	// cf. public/assembler.php)
-	echo pipeline('affichage_final', $page['texte']);
+	echo pipeline('affichage_final'._PIPELINE_SUFFIX, $page['texte']);
 
 	if ($lang) lang_select();
 	// l'affichage de la page a pu lever des erreurs (inclusion manquante)
@@ -209,14 +163,12 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 	if ($debug) {
 		// en cas d'erreur, retester l'affichage
 		if ($html AND ($affiche_boutons_admin OR $debug)) {
-			if (!_request('var_mode_affiche'))
-				set_request('var_mode_affiche', 'resultat');
 			$var_mode_affiche = _request('var_mode_affiche');
-			$var_mode_objet = _request('var_mode_objet');
 			$GLOBALS['debug_objets'][$var_mode_affiche][$var_mode_objet . 'tout'] = ($var_mode_affiche== 'validation' ? $page['texte'] :"");
 			echo erreur_squelette(false);
 		}
 	} else {
+
 		if (isset($GLOBALS['meta']['date_prochain_postdate'])
 		AND $GLOBALS['meta']['date_prochain_postdate'] <= time()) {
 			include_spip('inc/rubriques');
@@ -224,26 +176,13 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 		}
 
 		// Effectuer une tache de fond ?
-		// si #SPIP_CRON est present, on ne le tente que pour les navigateurs
-		// en mode texte (par exemple), et seulement sur les pages web
-		if (defined('_DIRECT_CRON_FORCE')
-			OR (
-			!defined('_DIRECT_CRON_INHIBE')
-			AND $html
-			AND !strstr($page['texte'], '<!-- SPIP-CRON -->')
-			AND !preg_match(',msie|mozilla|opera|konqueror,i', $_SERVER['HTTP_USER_AGENT']))
-			)
+		// si _DIRECT_CRON_FORCE est present, on force l'appel
+		if (defined('_DIRECT_CRON_FORCE'))
 			cron();
 
 		// sauver le cache chemin si necessaire
 		save_path_cache();
 	}
-
- 	// Gestion des statistiques du site public
-	if (($GLOBALS['meta']["activer_statistiques"] != "non")
-	AND $spip_compter_visites!='non'
-	AND $stats = charger_fonction('stats', 'public', true))
-		$stats();
 }
 
 ?>
