@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2013                                                *
+ *  Copyright (c) 2001-2014                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -22,28 +22,35 @@ if (!defined('_CONTEXTE_IGNORE_VARIABLES')) define('_CONTEXTE_IGNORE_VARIABLES',
 // http://doc.spip.org/@assembler
 function assembler($fond, $connect='') {
 
-	global $flag_preserver,$lastmodified, $use_cache, $contexte;
+	// flag_preserver est modifie ici, et utilise en globale
+	// use_cache sert a informer le bouton d'admin pr savoir s'il met un *
+	// contexte est utilise en globale dans le formulaire d'admin
+	global $flag_preserver, $use_cache, $contexte;
 
 	$contexte = calculer_contexte();
 	$page = array('contexte_implicite'=>calculer_contexte_implicite());
 	$page['contexte_implicite']['cache'] = $fond . preg_replace(',\.[a-zA-Z0-9]*$,', '', preg_replace('/[?].*$/', '', $GLOBALS['REQUEST_URI']));
 	// Cette fonction est utilisee deux fois
-	$cacher = charger_fonction('cacher', 'public');
+	$cacher = charger_fonction('cacher', 'public', true);
 	// Les quatre derniers parametres sont modifies par la fonction:
 	// emplacement, validite, et, s'il est valide, contenu & age
-	$res = $cacher($GLOBALS['contexte'], $use_cache, $chemin_cache, $page, $lastmodified);
+	if ($cacher)
+		$res = $cacher($GLOBALS['contexte'], $use_cache, $chemin_cache, $page, $lastmodified);
+	else
+		$use_cache = -1;
 	// Si un resultat est retourne, c'est un message d'impossibilite
 	if ($res) {return array('texte' => $res);}
 
 	if (!$chemin_cache || !$lastmodified) $lastmodified = time();
 
 	$headers_only = ($_SERVER['REQUEST_METHOD'] == 'HEAD');
+	$calculer_page = true;
 
 	// Pour les pages non-dynamiques (indiquees par #CACHE{duree,cache-client})
 	// une perennite valide a meme reponse qu'une requete HEAD (par defaut les
 	// pages sont dynamiques)
 	if (isset($_SERVER['HTTP_IF_MODIFIED_SINCE'])
-	AND !$GLOBALS['var_mode']
+	AND (!defined('_VAR_MODE') OR !_VAR_MODE)
 	AND $chemin_cache
 	AND isset($page['entetes'])
 	AND isset($page['entetes']['Cache-Control'])
@@ -56,80 +63,46 @@ function assembler($fond, $connect='') {
 		if (trim($since) == gmdate("D, d M Y H:i:s", $lastmodified)) {
 			$page['status'] = 304;
 			$headers_only = true;
+			$calculer_page = false;
 		}
 	}
 
 	// Si requete HEAD ou Last-modified compatible, ignorer le texte
 	// et pas de content-type (pour contrer le bouton admin de inc-public)
-	if ($headers_only) {
-		$page['entetes']["Connection"] = "close";
+	if (!$calculer_page) {
 		$page['texte'] = "";
 	} else {
 		// si la page est prise dans le cache
 		if (!$use_cache)  {
-		// Informer les boutons d'admin du contexte
-		// (fourni par $renommer ci-dessous lors de la mise en cache)
+			// Informer les boutons d'admin du contexte
+			// (fourni par urls_decoder_url ci-dessous lors de la mise en cache)
 			$contexte = $page['contexte'];
 
 			// vider les globales url propres qui ne doivent plus etre utilisees en cas
 			// d'inversion url => objet
-			unset($_SERVER['REDIRECT_url_propre']);
-			unset($_ENV['url_propre']);
+			// plus necessaire si on utilise bien la fonction urls_decoder_url
+			#unset($_SERVER['REDIRECT_url_propre']);
+			#unset($_ENV['url_propre']);
 		}
-		// ATTENTION, gestion des URLs transformee par le htaccess
-		// $renommer = 'urls_propres_dist';
-		// renvoie array($contexte, $type, $url_redirect, $nfond)
-		// $nfond n'est retourne que si l'url est definie apres le ?
-		// et risque d'etre effacee par un form en get
-		// elle est utilisee par form_hidden exclusivement
-		// Compat ascendante si le retour est null:
-		// 1. $contexte est global car cette fonction le modifie.
-		// 2. $fond est passe par reference, pour la meme raison
-		// et calculer la page
 		else {
-			$renommer = generer_url_entite();
-			if ($renommer) {
-				$url = nettoyer_uri();
-				$a = $renommer($url, $fond, $contexte);
-				if (is_array($a)) {
-					list($ncontexte, $type, $url_redirect, $nfond) = $a;
-					if (strlen($url_redirect)
-					AND $url !== $url_redirect) {
-						spip_log("Redirige $url vers $url_redirect");
-						include_spip('inc/headers');
-						redirige_par_entete($url_redirect, '', 301);
-					}
-					if (isset($nfond))
-						$fond = $nfond;
-					else if ($fond == ''
-					OR $fond == 'type_urls' /* compat avec htaccess 2.0.0 */
-					)
-						$fond = ($type === 'syndic') ? 'site' : $type;
-					if (isset($ncontexte))
-						$contexte = $ncontexte;
-					if (defined('_DEFINIR_CONTEXTE_TYPE') AND _DEFINIR_CONTEXTE_TYPE)
-						$contexte['type'] = ($type === 'syndic') ? 'site' : $type;
-				}
+			// Compat ascendante :
+			// 1. $contexte est global
+			// (a evacuer car urls_decoder_url gere ce probleme ?)
+			// et calculer la page
+			if (!test_espace_prive()) {
+				include_spip('inc/urls');
+				list($fond,$contexte,$url_redirect) = urls_decoder_url(nettoyer_uri(),$fond,$contexte,true);
 			}
-			// compatibilite <= 1.9.2
-			elseif (function_exists('recuperer_parametres_url'))
-				recuperer_parametres_url($fond, nettoyer_uri());
-
-			// vider les globales url propres qui ne doivent plus etre utilisees en cas
-			// d'inversion url => objet
-			unset($_SERVER['REDIRECT_url_propre']);
-			unset($_ENV['url_propre']);
-
 			// squelette par defaut
 			if (!strlen($fond))
 				$fond = 'sommaire';
 
 			// produire la page : peut mettre a jour $lastmodified
 			$produire_page = charger_fonction('produire_page','public');
-			$page = $produire_page($fond, $GLOBALS['contexte'], $use_cache, $chemin_cache, NULL, $page, $lastmodified, $connect);
+			$page = $produire_page($fond, $contexte, $use_cache, $chemin_cache, NULL, $page, $lastmodified, $connect);
 			if ($page === '') {
 				$erreur = _T('info_erreur_squelette2',
-					array('fichier'=>htmlspecialchars($fond).'.'._EXTENSION_SQUELETTES));
+					array('fichier'=>spip_htmlspecialchars($fond).'.'._EXTENSION_SQUELETTES));
 				erreur_squelette($erreur);
 				// eviter des erreurs strictes ensuite sur $page['cle'] en PHP >= 5.4
 				$page = array('texte' => '', 'erreur' => $erreur);
@@ -147,24 +120,14 @@ function assembler($fond, $connect='') {
 			if ($GLOBALS['flag_ob']) {
 				// Si la page est vide, produire l'erreur 404 ou message d'erreur pour les inclusions
 				if (trim($page['texte']) === ''
-				AND $GLOBALS['var_mode'] != 'debug'
+				AND _VAR_MODE != 'debug'
 				AND !isset($page['entetes']['Location']) // cette page realise une redirection, donc pas d'erreur
 				) {
-					// passer le type d'objet recherche au contexte de la page d'erreur
-					$contexte['type'] = (isset($type)?$type:$fond);
+					$contexte['fond_erreur'] = $fond;
 				  $page = message_page_indisponible($page, $contexte);
-					// cacher la page d'erreur car celle ci est contextuelle
-					if ($chemin_cache
-					AND is_array($page)
-					AND count($page)
-					AND $page['entetes']['X-Spip-Cache'] > 0){
-						$cacher = charger_fonction('cacher', 'public');
-						$lastinclude = time();
-						$cacher($contexte_cache, $use_cache, $chemin_cache, $page, $lastinclude);
-					}
 				}
 				// pas de cache client en mode 'observation'
-				if ($GLOBALS['var_mode']) {
+				if (defined('_VAR_MODE') AND _VAR_MODE) {
 					$page['entetes']["Cache-Control"]= "no-cache,must-revalidate";
 					$page['entetes']["Pragma"] = "no-cache";
 				}
@@ -180,6 +143,10 @@ function assembler($fond, $connect='') {
 	AND !isset($page['entetes']["Last-Modified"]))
 		$page['entetes']["Last-Modified"]=gmdate("D, d M Y H:i:s", $lastmodified)." GMT";
 
+	// fermer la connexion apres les headers si requete HEAD
+	if ($headers_only)
+		$page['entetes']["Connection"] = "close";
+
 	return $page;
 }
 
@@ -216,14 +183,16 @@ function calculer_contexte() {
 function calculer_contexte_implicite(){
 	static $notes = null;
 	if (is_null($notes))
-		$notes = charger_fonction('notes','inc');
+		$notes = charger_fonction('notes','inc',true);
 	$contexte_implicite = array(
 		'squelettes' => $GLOBALS['dossier_squelettes'], // devrait etre 'chemin' => $GLOBALS['path_sig'], ?
 		'host' => $_SERVER['HTTP_HOST'],
-		'https' => $_SERVER['HTTPS'],
+		'https' => (isset($_SERVER['HTTPS']) ? $_SERVER['HTTPS'] : ''),
 		'espace' => test_espace_prive(),
 		'marqueur' => (isset($GLOBALS['marqueur']) ?  $GLOBALS['marqueur'] : ''),
-		'notes' => $notes('','contexter_cache'),
+		'marqueur_skel' => (isset($GLOBALS['marqueur_skel']) ?  $GLOBALS['marqueur_skel'] : ''),
+		'notes' => $notes?$notes('','contexter_cache'):'',
+		'spip_version_code' => $GLOBALS['spip_version_code'],
 	);
 	return $contexte_implicite;
 }
@@ -244,7 +213,7 @@ function auto_content_type($page)
 
 // http://doc.spip.org/@inclure_page
 function inclure_page($fond, $contexte, $connect='') {
-
+	static $cacher, $produire_page;
 	global $lastmodified;
 
 	// enlever le fond de contexte inclus car sinon il prend la main
@@ -253,10 +222,14 @@ function inclure_page($fond, $contexte, $connect='') {
 	unset($contexte['fond']);
 	$page = array('contexte_implicite'=>calculer_contexte_implicite());
 	$page['contexte_implicite']['cache'] = $fond;
-	$cacher = charger_fonction('cacher', 'public');
+	if (is_null($cacher))
+		$cacher = charger_fonction('cacher', 'public', true);
 	// Les quatre derniers parametres sont modifies par la fonction:
 	// emplacement, validite, et, s'il est valide, contenu & age
-	$res = $cacher($contexte, $use_cache, $chemin_cache, $page, $lastinclude);
+	if ($cacher)
+		$res = $cacher($contexte, $use_cache, $chemin_cache, $page, $lastinclude);
+	else
+		$use_cache = -1;
 	// $res = message d'erreur : on sort de la
 	if ($res) {return array('texte' => $res);}
 
@@ -264,7 +237,8 @@ function inclure_page($fond, $contexte, $connect='') {
 	// produire la page : peut mettre a jour $lastinclude
 	// le contexte_cache envoye a cacher() a ete conserve et est passe a produire
 	if ($use_cache) {
-		$produire_page = charger_fonction('produire_page','public');
+		if (is_null($produire_page))
+			$produire_page = charger_fonction('produire_page','public');
 		$page = $produire_page($fond, $contexte, $use_cache, $chemin_cache, $contexte, $page, $lastinclude, $connect);
 	}
 	// dans tous les cas, mettre a jour $lastmodified
@@ -288,8 +262,9 @@ function inclure_page($fond, $contexte, $connect='') {
  * @return array
  */
 function public_produire_page_dist($fond, $contexte, $use_cache, $chemin_cache, $contexte_cache, &$page, &$lastinclude, $connect=''){
-	#var_dump($page);
-	$parametrer = charger_fonction('parametrer', 'public');
+	static $parametrer,$cacher;
+	if (!$parametrer)
+		$parametrer = charger_fonction('parametrer', 'public');
 	$page = $parametrer($fond, $contexte, $chemin_cache, $connect);
 	// et on l'enregistre sur le disque
 	if ($chemin_cache
@@ -297,9 +272,13 @@ function public_produire_page_dist($fond, $contexte, $use_cache, $chemin_cache,
 	AND is_array($page)
 	AND count($page)
 	AND $page['entetes']['X-Spip-Cache'] > 0){
-		$cacher = charger_fonction('cacher', 'public');
+		if (is_null($cacher))
+			$cacher = charger_fonction('cacher', 'public', true);
 		$lastinclude = time();
-		$cacher($contexte_cache, $use_cache, $chemin_cache, $page, $lastinclude);
+		if ($cacher)
+			$cacher($contexte_cache, $use_cache, $chemin_cache, $page, $lastinclude);
+		else
+			$use_cache = -1;
 	}
 	return $page;
 }
@@ -355,20 +334,26 @@ function inclure_balise_dynamique($texte, $echo=true, $contexte_compil=array())
 					array_merge($GLOBALS['page']['entetes'],$page['entetes']);
 			}
 		}
-		// on se refere a $page['contexte'] a la place
-		if (isset($page['contexte']['_pipeline'])) {
-			$pipe = is_array($page['contexte']['_pipeline'])?reset($page['contexte']['_pipeline']):$page['contexte']['_pipeline'];
-			$args = is_array($page['contexte']['_pipeline'])?end($page['contexte']['_pipeline']):array();
-			$args['contexte'] = $page['contexte'];
-			unset($args['contexte']['_pipeline']); // par precaution, meme si le risque de boucle infinie est a priori nul
-			if (isset($GLOBALS['spip_pipeline'][$pipe]))
-				$texte = pipeline($pipe,array(
-				  'data'=>$texte,
-				  'args'=>$args));
+		// _pipelines au pluriel array('nom_pipeline' => $args...) avec une syntaxe permettant plusieurs pipelines
+		if (isset($page['contexte']['_pipelines'])
+		  AND is_array($page['contexte']['_pipelines'])
+			AND count($page['contexte']['_pipelines'])) {
+			foreach($page['contexte']['_pipelines'] as $pipe=>$args){
+				$args['contexte'] = $page['contexte'];
+				unset($args['contexte']['_pipelines']); // par precaution, meme si le risque de boucle infinie est a priori nul
+				$texte = pipeline(
+					$pipe,
+					array(
+						'data'=>$texte,
+						'args'=>$args
+					),
+					false
+				);
+			}
 		}
 	}
 
-	if ($GLOBALS['var_mode'] == 'debug') {
+	if (defined('_VAR_MODE') AND _VAR_MODE == 'debug') {
 		// compatibilite : avant on donnait le numero de ligne ou rien.
 		$ligne =  intval(isset($contexte_compil[3]) ? $contexte_compil[3] : $contexte_compil);
 		$GLOBALS['debug_objets']['resultat'][$ligne] = $texte;
@@ -380,73 +365,6 @@ function inclure_balise_dynamique($texte, $echo=true, $contexte_compil=array())
 
 }
 
-// Traiter var_recherche ou le referrer pour surligner les mots
-// http://doc.spip.org/@f_surligne
-function f_surligne ($texte) {
-	if (!$GLOBALS['html']) return $texte;
-	$rech = _request('var_recherche');
-	if (!$rech AND !isset($_SERVER['HTTP_REFERER'])) return $texte;
-	include_spip('inc/surligne');
-	return surligner_mots($texte, $rech);
-}
-
-// Valider/indenter a la demande.
-// http://doc.spip.org/@f_tidy
-function f_tidy ($texte) {
-	global $xhtml;
-
-	if ($xhtml # tidy demande
-	AND $GLOBALS['html'] # verifie que la page avait l'entete text/html
-	AND strlen($texte)
-	AND !headers_sent()) {
-		# Compatibilite ascendante
-		if (!is_string($xhtml)) $xhtml ='tidy';
-
-		if (!$f = charger_fonction($xhtml, 'inc', true)) {
-			spip_log("tidy absent, l'indenteur SPIP le remplace");
-			$f = charger_fonction('sax', 'xml');
-		}
-		return $f($texte);
-	}
-
-	return $texte;
-}
-
-// Offre #INSERT_HEAD sur tous les squelettes (bourrin)
-// a activer dans mes_options via :
-// $spip_pipeline['affichage_final'] .= '|f_insert_head';
-// http://doc.spip.org/@f_insert_head
-function f_insert_head($texte) {
-	if (!$GLOBALS['html']) return $texte;
-	include_spip('public/admin'); // pour strripos
-
-	($pos = stripos($texte, '</head>'))
-	    || ($pos = stripos($texte, '<body>'))
-	    || ($pos = 0);
-
-	if (false === strpos(substr($texte, 0,$pos), '<!-- insert_head -->')) {
-		$insert = "\n".pipeline('insert_head','<!-- f_insert_head -->')."\n";
-		$texte = substr_replace($texte, $insert, $pos, 0);
-	}
-
-	return $texte;
-}
-
-// Inserer au besoin les boutons admins
-// http://doc.spip.org/@f_admin
-function f_admin ($texte) {
-	if (!$GLOBALS['html']) return $texte;
-	if ($GLOBALS['affiche_boutons_admin']) {
-		include_spip('public/admin');
-		$texte = affiche_boutons_admin($texte);
-	}
-	if (_request('var_mode')=='noajax'){
-		$texte = preg_replace(',(class=[\'"][^\'"]*)ajax([^\'"]*[\'"]),Uims',"\\1\\2",$texte);
-	}
-	return $texte;
-}
-
-
 // http://doc.spip.org/@message_page_indisponible
 function message_page_indisponible ($page, $contexte) {
 	static $deja = false;
@@ -459,7 +377,6 @@ function message_page_indisponible ($page, $contexte) {
 	$contexte['status'] = ($page !== false) ? '404' : '503';
 	$contexte['code'] = $codes[$contexte['status']];
 	$contexte['fond'] = '404'; // gere les 2 erreurs
-	$contexte['erreur'] = _T($erreur);
 	if (!isset($contexte['lang']))
 		$contexte['lang'] = $GLOBALS['spip_lang'];
 
@@ -473,6 +390,7 @@ function message_page_indisponible ($page, $contexte) {
 	if (!$page)
 		$page = inclure_page('404', $contexte);
 	$page['status'] = $contexte['status'];
+
 	return $page;
 }
 
@@ -503,7 +421,7 @@ function creer_contexte_de_modele($args) {
 
 // Calcule le modele et retourne la mini-page ainsi calculee
 // http://doc.spip.org/@inclure_modele
-function inclure_modele($type, $id, $params, $lien, $connect='') {
+function inclure_modele($type, $id, $params, $lien, $connect='', $env=array()) {
 
 	static $compteur;
 	if (++$compteur>10) return ''; # ne pas boucler indefiniment
@@ -533,21 +451,21 @@ function inclure_modele($type, $id, $params, $lien, $connect='') {
 	}
 
 	// Si ca marche pas en precisant le sous-type, prendre le type
-	if (!$fond AND !trouve_modele($fond = $type))
+	if (!$fond AND !trouve_modele($fond = $type)){
+		spip_log("Modele $type introuvable",_LOG_INFO_IMPORTANTE);
 		return false;
+	}
 	$fond = 'modeles/'.$fond;
 	// Creer le contexte
-	$contexte = array( 
-		'dir_racine' => _DIR_RACINE # eviter de mixer un cache racine et un cache ecrire (meme si pour l'instant les modeles ne sont pas caches, le resultat etant different il faut que le contexte en tienne compte 
-	); 
+	$contexte = $env;
+	$contexte['dir_racine'] = _DIR_RACINE; # eviter de mixer un cache racine et un cache ecrire (meme si pour l'instant les modeles ne sont pas caches, le resultat etant different il faut que le contexte en tienne compte
+
 	// Le numero du modele est mis dans l'environnement
 	// d'une part sous l'identifiant "id"
-	// et d'autre part sous l'identifiant de la cle primaire supposee
-	// par la fonction table_objet, 
-	// qui ne marche vraiment que pour les tables std de SPIP
-	// (<site1> =>> site =>> id_syndic =>> id_syndic=1)
-	$_id = 'id_' . table_objet($type);
-	if (preg_match('/s$/',$_id)) $_id = substr($_id,0,-1);
+	// et d'autre part sous l'identifiant de la cle primaire
+	// par la fonction id_table_objet,
+	// (<article1> =>> article =>> id_article =>> id_article=1)
+	$_id = id_table_objet($type);
 	$contexte['id'] = $contexte[$_id] = $id;
 
 	if (isset($class))
@@ -581,6 +499,7 @@ function inclure_modele($type, $id, $params, $lien, $connect='') {
 			trim(str_replace(' spip_lien_ok ', ' ', " $classes ")));
 	} else if ($lien)
 		$retour = "<a href='".$lien['href']."' class='".$lien['class']."'>".$retour."</a>";
+
 	$compteur--;
 
 	return  (isset($arg_list['ajax'])AND $arg_list['ajax']=='ajax')
@@ -598,24 +517,9 @@ function evaluer_fond ($fond, $contexte=array(), $connect=null) {
 	$page = inclure_page($fond, $contexte, $connect);
 
 	if (!$page) return $page;
-
-	if ($page['process_ins'] != 'html') {
-		// restaurer l'etat des notes
-		if (isset($page['notes']) AND $page['notes']){
-			$notes = charger_fonction("notes","inc");
-			$notes($page['notes'],'restaurer_etat');
-		}
-
-		ob_start();
-		xml_hack($page, true);
-		eval('?' . '>' . $page['texte']);
-		$page['texte'] = ob_get_contents();
-		xml_hack($page);
-		$page['process_ins'] = 'html';
-		ob_end_clean();
-	}
-	page_base_href($page['texte']);
-
+	// eval $page et affecte $res
+	include _ROOT_RESTREINT."public/evaluer_page.php";
+	
 	// Lever un drapeau (global) si le fond utilise #SESSION
 	// a destination de public/parametrer
 	// pour remonter vers les inclusions appelantes
@@ -629,30 +533,26 @@ function evaluer_fond ($fond, $contexte=array(), $connect=null) {
 }
 
 
-// Appeler avant et apres chaque eval()
-// http://doc.spip.org/@xml_hack
-function xml_hack(&$page, $echap = false) {
-	if ($echap)
-		$page['texte'] = str_replace('<'.'?xml', "<\1?xml", $page['texte']);
-	else
-		$page['texte'] = str_replace("<\1?xml", '<'.'?xml', $page['texte']);
-}
-
 // http://doc.spip.org/@page_base_href
 function page_base_href(&$texte){
-	if (!defined('_SET_HTML_BASE'))
-		// si la profondeur est superieure a 1
-		// est que ce n'est pas une url page ni une url action
-		// activer par defaut
-		define('_SET_HTML_BASE',
-			$GLOBALS['profondeur_url'] >= (_DIR_RESTREINT?1:2)
-			AND _request(_SPIP_PAGE) !== 'login'
-			AND !_request('action'));
+	static $set_html_base = null;
+	if (is_null($set_html_base)){
+		if (!defined('_SET_HTML_BASE'))
+			// si la profondeur est superieure a 1
+			// est que ce n'est pas une url page ni une url action
+			// activer par defaut
+			$set_html_base = ((
+				$GLOBALS['profondeur_url'] >= (_DIR_RESTREINT?1:2)
+				AND _request(_SPIP_PAGE) !== 'login'
+				AND !_request('action'))?true:false);
+		else
+			$set_html_base = _SET_HTML_BASE;
+	}
 
-	if (_SET_HTML_BASE
-	AND isset($GLOBALS['html']) AND $GLOBALS['html']
-	AND $GLOBALS['profondeur_url']>0
-	AND ($poshead = strpos($texte,'</head>'))!==FALSE){
+	if ($set_html_base
+	  AND isset($GLOBALS['html']) AND $GLOBALS['html']
+	  AND $GLOBALS['profondeur_url']>0
+	  AND ($poshead = strpos($texte,'</head>'))!==FALSE){
 		$head = substr($texte,0,$poshead);
 		$insert = false;
 		if (strpos($head, '<base')===false) 
@@ -687,19 +587,6 @@ function page_base_href(&$texte){
 	}
 }
 
-function public_previsualisation_dist($page)
-{
-	if (preg_match(',^\s*text/html,',$page['entetes']['Content-Type'])) {
-		include_spip('inc/filtres'); // pour http_img_pack
-		$x = _T('previsualisation');
-		$x = http_img_pack('naviguer-site.png', $x) . '&nbsp;' . majuscules($x); 
-		$x = "<div class='spip-previsu'>$x</div>";
-		if (!$pos = strpos($page['texte'], '</body>'))
-			$pos = strlen($page['texte']);
-		$page['texte'] = substr_replace($page['texte'], $x, $pos, 0);
-	}
-	return $page;
-}
 
 // Envoyer les entetes, en retenant ceux qui sont a usage interne
 // et demarrent par X-Spip-...
@@ -707,7 +594,7 @@ function public_previsualisation_dist($page)
 function envoyer_entetes($entetes) {
 	foreach ($entetes as $k => $v)
 	#	if (strncmp($k, 'X-Spip-', 7))
-			@header($v?"$k: $v":$k);
+			@header(strlen($v)?"$k: $v":$k); 
 }
 
 ?>
